import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeTableau10,
} from 'd3';

const svg = select("svg");
const width = window.innerWidth;
const height = window.innerHeight; 
const numberFormat = number =>
  	(Math.abs(Number(number))) ;

//rendering data from csv and object for generating arcs
const render = data => {
  const pieData = pie().sort(null).value(d=>d.Number)(data);
  const colors = scaleOrdinal(schemeTableau10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(180)
  	.padAngle(0)
  	.padRadius(0);
  //arc is generated for each element in pie chart
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);
  
  //append the baby names data
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  //colors is atatched with each and every element
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Number))
  	.on("mouseover", d => console.log(d.data.Number));
  //value of each element is attached here
  sections
    .enter()
    .append('text')
    .text(d => d.data.Number)
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  //piechart is created on canvas
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });

  //adding legends -telling about shape of box and to display name and number beside boxes.
  legend.append("rect").attr("width",22).attr("height",25).attr("x", 38)
  	.attr("y", -30)
  	.attr("fill", d => colors(d.data.Number));
  //add baby names to legend
  legend.append("text")
  	.attr("x", 68)
  	.attr("y", -10)
  	.attr("class","legend_text")
  	.text(d => d.data.Name);
  //add number to legend
  legend.append("text")
  	.attr("x", 300)
  	.attr("y", -10)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.Number));
}
//import dataset from gist
const csvUrl =
 'https://gist.githubusercontent.com/Jasvitha/06dfbf4e124d3d85274f7b1bb00f80de/raw/c24c17558d2d68d9a941b5501cc233ec5a13c5c2/Baby_names.csv';


//Load the data and display 10 baby names and their numbers 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.Number-data1.Number);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});